import { Asset, AnyChain, SetOptional, ChainAsset, AnyAsset, Ecosystem, Parachain, EvmParachain, EvmChain } from '@moonbeam-network/xcm-types';
import { ContractConfigBuilder, ExtrinsicConfigBuilder, BalanceConfigBuilder, AssetMinConfigBuilder, MrlConfigBuilder, FeeConfigBuilder } from '@moonbeam-network/xcm-builder';

interface AssetRouteConstructorParams {
    source: SourceConfig;
    destination: DestinationConfig;
    contract?: ContractConfigBuilder;
    extrinsic?: ExtrinsicConfigBuilder;
    mrl?: MrlConfig;
}
interface SourceConfig {
    asset: Asset;
    chain: AnyChain;
    balance: BalanceConfigBuilder;
    fee?: FeeConfig;
    destinationFee?: {
        asset?: Asset;
        balance: BalanceConfigBuilder;
    };
    min?: AssetMinConfigBuilder;
}
interface DestinationConfig extends Omit<SourceConfig, 'fee'> {
    fee: DestinationFeeConfig;
}
interface FeeConfig {
    asset: Asset;
    balance: BalanceConfigBuilder;
    extra?: number;
}
interface MrlConfig {
    isAutomaticPossible: boolean;
    transfer: MrlConfigBuilder;
    moonChain: MoonChainConfig;
}
interface DestinationFeeConfig extends SetOptional<FeeConfig, 'balance'> {
    amount: number | FeeConfigBuilder;
}
interface MoonChainConfig {
    asset: Asset;
    balance: BalanceConfigBuilder;
    fee: MoonChainFeeConfig;
}
interface MoonChainFeeConfig extends FeeConfig {
    amount: number | FeeConfigBuilder;
}
declare class AssetRoute {
    readonly source: SourceConfig;
    readonly destination: DestinationConfig;
    readonly contract?: ContractConfigBuilder;
    readonly extrinsic?: ExtrinsicConfigBuilder;
    readonly mrl?: MrlConfig;
    constructor({ source, destination, contract, extrinsic, mrl, }: AssetRouteConstructorParams);
    getDestinationFeeAssetOnSource(): ChainAsset;
}

interface ChainRoutesConstructorParams {
    chain: AnyChain;
    routes: RoutesParam[];
}
interface RoutesParam extends Omit<AssetRouteConstructorParams, 'source'> {
    source: Omit<SourceConfig, 'chain'>;
}
declare class ChainRoutes {
    #private;
    readonly chain: AnyChain;
    constructor({ chain, routes }: ChainRoutesConstructorParams);
    getRoutes(): AssetRoute[];
    getAssetRoutes(keyOrAsset: string | AnyAsset): AssetRoute[];
    getAssetDestinations(keyOrAsset: string | AnyAsset): AnyChain[];
    getDestinationAssets(keyOrChain: string | AnyChain): Asset[];
    getAssetRoute(asset: string | AnyAsset, destination: string | AnyChain): AssetRoute;
}

interface MrlAssetRouteConstructorParams extends AssetRouteConstructorParams {
    source: MrlSourceConfig;
}
interface MrlSourceConfig extends SourceConfig {
    moonChainFee?: {
        asset: Asset;
        balance: BalanceConfigBuilder;
    };
}
declare class MrlAssetRoute extends AssetRoute {
    readonly source: MrlSourceConfig;
    constructor({ source, destination, contract, extrinsic, mrl, }: MrlAssetRouteConstructorParams & {
        source: MrlSourceConfig;
    });
}

interface MrlChainRoutesConstructorParams extends ChainRoutesConstructorParams {
    routes: MrlRoutesParam[];
}
interface MrlRoutesParam extends Omit<MrlAssetRouteConstructorParams, 'source'> {
    source: Omit<MrlSourceConfig, 'chain'>;
}
declare class MrlChainRoutes extends ChainRoutes {
    #private;
    constructor({ chain, routes }: MrlChainRoutesConstructorParams);
    getRoutes(): MrlAssetRoute[];
}

interface ConfigServiceOptions {
    assets?: Map<string, Asset>;
    chains?: Map<string, AnyChain>;
    routes: Map<string, ChainRoutes | MrlChainRoutes>;
}
declare class ConfigService {
    protected assets: Map<string, Asset>;
    protected chains: Map<string, AnyChain>;
    protected routes: Map<string, ChainRoutes | MrlChainRoutes>;
    constructor(options: ConfigServiceOptions);
    getAsset(keyOrAsset: string | Asset): Asset;
    getEcosystemAssets(ecosystem?: Ecosystem): Asset[];
    getChain(keyOrChain: string | AnyChain): AnyChain;
    getChainRoutes(keyOrChain: string | AnyChain): ChainRoutes | MrlChainRoutes;
    getSourceChains({ asset, ecosystem, }: {
        asset?: string | Asset;
        ecosystem?: Ecosystem;
    }): AnyChain[];
    getDestinationChains({ asset, source, }: {
        asset?: string | AnyAsset;
        source: string | AnyChain;
    }): AnyChain[];
    getAssetRoute({ asset, source, destination, }: {
        asset: string | AnyAsset;
        source: string | AnyChain;
        destination: string | AnyChain;
    }): AssetRoute | MrlAssetRoute;
    getRouteAssets({ source, destination, }: {
        source: string | AnyChain;
        destination: string | AnyChain;
    }): Asset[];
    updateAsset(asset: Asset): void;
    updateChain(chain: AnyChain): void;
    updateChainRoute(route: ChainRoutes): void;
}

declare const aca: Asset;
declare const agng: Asset;
declare const alan: Asset;
declare const ampe: Asset;
declare const apillon: Asset;
declare const aseed: Asset;
declare const astr: Asset;
declare const atom: Asset;
declare const auq: Asset;
declare const axlusdc: Asset;
declare const betaDEV: Asset;
declare const bnc: Asset;
declare const bncs: Asset;
declare const cfg: Asset;
declare const crab: Asset;
declare const csm: Asset;
declare const dai: Asset;
declare const ded: Asset;
declare const dev: Asset;
declare const dot: Asset;
declare const eq: Asset;
declare const eqd: Asset;
declare const eth: Asset;
declare const fil: Asset;
declare const ftm: Asset;
declare const ftmwh: Asset;
declare const glmr: Asset;
declare const hdx: Asset;
declare const ibtc: Asset;
declare const intr: Asset;
declare const kar: Asset;
declare const kbtc: Asset;
declare const kint: Asset;
declare const kma: Asset;
declare const ksm: Asset;
declare const ldot: Asset;
declare const lit: Asset;
declare const manta: Asset;
declare const mgx: Asset;
declare const movr: Asset;
declare const neuro: Asset;
declare const nodl: Asset;
declare const otp: Asset;
declare const para: Asset;
declare const paring: Asset;
declare const peaq: Asset;
declare const pen: Asset;
declare const pha: Asset;
declare const pica: Asset;
declare const pink: Asset;
declare const ring: Asset;
declare const rmrk: Asset;
declare const sdn: Asset;
declare const soon: Asset;
declare const stink: Asset;
declare const sub: Asset;
declare const teer: Asset;
declare const tnkr: Asset;
declare const tt1: Asset;
declare const tur: Asset;
declare const unit: Asset;
declare const usdc: Asset;
declare const usdcwh: Asset;
declare const usdt: Asset;
declare const usdtwh: Asset;
declare const vastr: Asset;
declare const vbnc: Asset;
declare const vdot: Asset;
declare const vfil: Asset;
declare const vglmr: Asset;
declare const vksm: Asset;
declare const vmanta: Asset;
declare const vmovr: Asset;
declare const wbtc: Asset;
declare const weth: Asset;
declare const wftm: Asset;
declare const wifd: Asset;
declare const xrt: Asset;
declare const ztg: Asset;
declare const wbtce: Asset;
declare const wstethe: Asset;
declare const wethe: Asset;
declare const assetsList: Asset[];
declare const assetsMap: Map<string, Asset>;

declare const acala: Parachain;
declare const alphanetAssetHub: Parachain;
declare const alphanetRelay: Parachain;
declare const astar: Parachain;
declare const bifrostKusama: Parachain;
declare const bifrostPolkadot: Parachain;
declare const calamari: Parachain;
declare const centrifuge: Parachain;
declare const crustShadow: Parachain;
declare const darwinia: EvmParachain;
declare const darwiniaCrab: EvmParachain;
declare const ethereum: EvmChain;
declare const fantomTestnet: EvmChain;
declare const hydration: Parachain;
declare const hydrationAlphanet: Parachain;
declare const integritee: Parachain;
declare const interlay: Parachain;
declare const karura: Parachain;
declare const khala: Parachain;
declare const kintsugi: Parachain;
declare const kusama: Parachain;
declare const kusamaAssetHub: Parachain;
declare const mangataKusama: Parachain;
declare const mantaParachain: Parachain;
declare const moonbaseAlpha: EvmParachain;
declare const moonbaseBeta: EvmParachain;
declare const moonbeam: EvmParachain;
declare const moonriver: EvmParachain;
declare const neuroweb: Parachain;
declare const originTrailAlphanet: Parachain;
declare const peaqAlphanet: Parachain;
declare const peaqChain: Parachain;
declare const peaqEvm: EvmParachain;
declare const peaqEvmAlphanet: EvmParachain;
declare const pendulum: Parachain;
declare const pendulumAlphanet: Parachain;
declare const phala: Parachain;
declare const picasso: Parachain;
declare const picassoAlphanet: Parachain;
declare const polkadot: Parachain;
declare const polkadotAssetHub: Parachain;
declare const robonomics: Parachain;
declare const shiden: Parachain;
declare const subsocial: Parachain;
declare const tinkernet: Parachain;
declare const turing: Parachain;
declare const turingAlphanet: Parachain;
declare const uniqueAlpha: Parachain;
declare const zeitgeist: Parachain;
declare const chainsList: AnyChain[];
declare const chainsMap: Map<string, AnyChain>;

declare function getKey(keyOrModel: string | AnyAsset | AnyChain): string;
declare function getMoonChain(chain: AnyChain): EvmParachain;

declare const mrlRoutesList: MrlChainRoutes[];
declare const mrlRoutesMap: Map<string, MrlChainRoutes>;

declare const xcmRoutesList: ChainRoutes[];
declare const xcmRoutesMap: Map<string, ChainRoutes>;

export { AssetRoute, type AssetRouteConstructorParams, ChainRoutes, type ChainRoutesConstructorParams, ConfigService, type ConfigServiceOptions, type DestinationConfig, type DestinationFeeConfig, type FeeConfig, type MoonChainConfig, type MoonChainFeeConfig, MrlAssetRoute, type MrlAssetRouteConstructorParams, MrlChainRoutes, type MrlChainRoutesConstructorParams, type MrlConfig, type MrlSourceConfig, type SourceConfig, aca, acala, agng, alan, alphanetAssetHub, alphanetRelay, ampe, apillon, aseed, assetsList, assetsMap, astar, astr, atom, auq, axlusdc, betaDEV, bifrostKusama, bifrostPolkadot, bnc, bncs, calamari, centrifuge, cfg, chainsList, chainsMap, crab, crustShadow, csm, dai, darwinia, darwiniaCrab, ded, dev, dot, eq, eqd, eth, ethereum, fantomTestnet, fil, ftm, ftmwh, getKey, getMoonChain, glmr, hdx, hydration, hydrationAlphanet, ibtc, integritee, interlay, intr, kar, karura, kbtc, khala, kint, kintsugi, kma, ksm, kusama, kusamaAssetHub, ldot, lit, mangataKusama, manta, mantaParachain, mgx, moonbaseAlpha, moonbaseBeta, moonbeam, moonriver, movr, mrlRoutesList, mrlRoutesMap, neuro, neuroweb, nodl, originTrailAlphanet, otp, para, paring, peaq, peaqAlphanet, peaqChain, peaqEvm, peaqEvmAlphanet, pen, pendulum, pendulumAlphanet, pha, phala, pica, picasso, picassoAlphanet, pink, polkadot, polkadotAssetHub, ring, rmrk, robonomics, sdn, shiden, soon, stink, sub, subsocial, teer, tinkernet, tnkr, tt1, tur, turing, turingAlphanet, uniqueAlpha, unit, usdc, usdcwh, usdt, usdtwh, vastr, vbnc, vdot, vfil, vglmr, vksm, vmanta, vmovr, wbtc, wbtce, weth, wethe, wftm, wifd, wstethe, xcmRoutesList, xcmRoutesMap, xrt, zeitgeist, ztg };
